// Next XMF message is 15, Module ID BASE_DCL

//    BASE.DCL      Version 1.1
//
//    Copyright (C) 1991-1994 by Autodesk, Inc.
//         
//    Permission to use, copy, modify, and distribute this software 
//    for any purpose and without fee is hereby granted, provided 
//    that the above copyright notice appears in all copies and that 
//    both that copyright notice and this permission notice appear in 
//    all supporting documentation.
//
//    THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT EXPRESS OR IMPLIED
//    WARRANTY.  ALL IMPLIED WARRANTIES OF FITNESS FOR ANY PARTICULAR
//    PURPOSE AND OF MERCHANTABILITY ARE HEREBY DISCLAIMED.

// Define common prototypes and subassemblies for use by
// ACAD.DCL (AutoCAD),
// ACLT.DCL (AutoCAD LT),
// ACVQ.DCL (AutoCAD VQ),
// and user-defined dialogs (AutoCAD).

// (The primitive widgets are set up automatically by init_dialog.  The
// equivalent DCL is shown here (commented out) for reference.)

// dialog {
//      layout          = vertical;
//      is_enabled      = false;
// }
// 
// cluster {
//      layout          = horizontal;
// }
// 
// radio_cluster {
//      layout          = horizontal;
//      is_enabled      = true;
// }
// 
// tile {
//      layout          = horizontal;
//      is_enabled      = true;
// }
// 
// text  : tile {
//      fixed_height    = true;       // inhibit vertical expansion
// }
// 
// image : tile {
// }
// 
// button : tile {
//      fixed_height    = true;
//      is_tab_stop     = true;
// }
// 
// image_button : button {
//      is_tab_stop     = true;
// }
// 
// toggle : tile {
//      fixed_height    = true;
//      is_tab_stop     = true;
// }
// 
// radio_button : tile {
//      fixed_height    = true;
//      is_tab_stop     = true;
// }
// 
// list_box : tile {
//      is_tab_stop     = true;
//      height          = 10;
//      width           = 10;
// }
// 
// edit_box : tile {
//      fixed_height    = true;
//      is_tab_stop     = true;
// }
// 
// popup_list : tile {
//      is_tab_stop     = true;
//      fixed_height    = true;
// }
// 
// slider : tile {
//      is_tab_stop     = true;
// }
// 
// spacer : tile {
// }

//----- Styles of clusters.

row : cluster {
    horizontal_margin = none;
    vertical_margin = none;
    children_alignment = centered;
}

column : cluster {
    layout = vertical;
    horizontal_margin = none;
    vertical_margin = none;
}

boxed_row : cluster {
    label = /*MSG0*/" ";
    boxed = true;
    children_alignment = centered;
}

boxed_column : cluster {
    label = /*MSG0*/" ";
    layout = vertical;
    boxed = true;
}

//----- Styles of radio clusters.

radio_row : radio_cluster {
    horizontal_margin = none;
    vertical_margin = none;
    children_alignment = centered;
}

radio_column : radio_cluster {
    layout = vertical;
    horizontal_margin = none;
    vertical_margin = none;
}

boxed_radio_row : radio_cluster {
    label = /*MSG0*/" ";
    boxed = true;
    children_alignment = centered;
}

boxed_radio_column : radio_cluster {
    label = /*MSG0*/" ";
    layout = vertical;
    boxed = true;
}

//----- Horizontal and vertical blocks of running text.

concatenation : cluster {
    fixed_width = true;
    fixed_height = true;
    children_alignment = centered;
}

paragraph : cluster {
    layout = vertical;
    fixed_height = true;
}

text_part : text {
    horizontal_margin = none;
    vertical_margin = none;
}

//----- Common spacers.

spacer_0 : spacer {
    height = 0;
    width = 0;
    horizontal_margin = none;
    vertical_margin = none;
}

spacer_1 : spacer {
    height = 1;
    width = 1;
    horizontal_margin = none;
    vertical_margin = none;
}

//----- The normal default widget.

default_button : button {
        is_default      = true;
}

//----- plain_cluster and plain_text are obsolete.  Use the new cluster
//      styles and running text prototypes above.

plain_cluster : cluster {
        horizontal_margin = none;
        vertical_margin = none;
}

plain_text  : text {                // text without margins
        horizontal_margin    = none;
        vertical_margin      = none;
}

//----- Standard prototype for making consistent "dialog retirement buttons".
//      Used below for the predefined retirement buttons, and for user-defined
//      dialogs that need retirement buttons with specialized verbs.

retirement_button : button {
        fixed_width     = true;
        width           = 8;
        alignment = centered;
}

//----- Standard dialog retirement buttons.  Unless one is building a dialog
//      retirement subassembly containing specialized verbs, these will 
//      normally not be used directly by DCL code outside of base.dcl; use
//      the pre-built subassemblies in the next section.

ok_button : retirement_button {
        label           = /*BASE_DCL_1*/"  OK  ";
        key             = /*MSG0*/"accept";
        is_default      = true;
}

cancel_button : retirement_button {
        label           = /*BASE_DCL_2*/"Cancel";
        key             = /*MSG0*/"cancel";
        is_cancel       = true;
}

help_button : retirement_button {
        label           = /*BASE_DCL_3*/"&Help...";
        key             = /*MSG0*/"help";
}

info_button : retirement_button {
        label           = /*BASE_DCL_4*/"&Info...";
        key             = /*MSG0*/"info";
}

//----- Pre-built arrays of dialog bottom-line buttons.

ok_only : column {
    fixed_width = true;
    alignment = centered;
    : ok_button {
        is_cancel = true;
    }
}

ok_cancel : column {
    : row {
        fixed_width = true;
        alignment = centered;
        ok_button;
        : spacer { width = 2; }
        cancel_button;
    }
}

ok_cancel_help : column {
    : row {
        fixed_width = true;
        alignment = centered;
        ok_button;
        : spacer { width = 2; }
        cancel_button;
        : spacer { width = 2; }
        help_button;
    }
}

ok_help : column {
    : row {
        fixed_width = true;
        alignment = centered;
        ok_button;
        : spacer { width = 2; }
        help_button;
    }
}

ok_cancel_help_info : column {
    : row {
        fixed_width = true;
        alignment = centered;
        ok_button;
        : spacer { width = 2; }
        cancel_button;
        : spacer { width = 2; }
        help_button;
        : spacer { width = 2; }
        info_button;
    }
}

//----- Error reporting tiles.

errtile : text {
        label = /*MSG0*/"";
        key = /*MSG0*/"error";
        width = 35;                   // must be long enough to hold error msgs
        is_error_tile = true;
}

// A custer consisting of OK, Cancel, and Help on one line with the error tile
//    below.

ok_cancel_help_errtile : column {
    ok_cancel_help;
    errtile;
}

// The same thing without the Help button for subdialogues that have no help
//    available.

ok_cancel_err : column {
    ok_cancel;
    errtile;
}

//-----For AutoCAD: Currently, the only dcl setting is the audit_level which
//     controls the level of semantic error checking applied during a 
//     load_dialog operation.  (0 = none, 1 = errors, 2 = warnings, 3 = hints)
// See AutoCAD's README for details.
//
// Audit is not supported in AutoCAD VQ.
default_dcl_settings : tile {
    audit_level = 1;
}

//----- Miscellaneous parts used by ACAD.DCL (AutoCAD),
//      ACLT.DCL (AutoCAD LT), and ACVQ.DCL (AutoCAD VQ).

image_block : image {
        key = /*MSG0*/"show_image";
        height = 1;
        width = 1;
}

icon_image : image_button {
        color                   = 0;
        width                   = 12;
        aspect_ratio            = 0.66;
        allow_accept            = true;
        fixed_height            = true;
        fixed_width             = true;
}

edit12_box : edit_box {
        edit_width = 12;
        edit_limit = 18;
}

//  The following are for the color-selection dialogs

swatch : image_button {
    vertical_margin = none;
    horizontal_margin = none;
    fixed_height = true;
    fixed_width = true;
    height = 1.5;
    width = 3;
}

color_palette_1_7 : row {             // Standard colors 1-7
    : swatch { color = 001; key = /*MSG0*/"001"; }
    : swatch { color = 002; key = /*MSG0*/"002"; }
    : swatch { color = 003; key = /*MSG0*/"003"; }
    : swatch { color = 004; key = /*MSG0*/"004"; }
    : swatch { color = 005; key = /*MSG0*/"005"; }
    : swatch { color = 006; key = /*MSG0*/"006"; }
    : swatch { color = 007; key = /*MSG0*/"007"; }
}

color_palette_1_9 : row {             // Standard colors, plus 8 and 9
    color_palette_1_7;
    : swatch { color = 008; key = /*MSG0*/"008"; }
    : swatch { color = 009; key = /*MSG0*/"009"; }
}

color_palette_0_9 : row {             // Standard colors, plus 0, 8, and 9
    : swatch { color = 000; key = /*MSG0*/"000"; }
    color_palette_1_9;
}

color_palette_250_255 : row {         // Grey shades 250-255
    : swatch { color = 250; key = /*MSG0*/"250"; }
    : swatch { color = 251; key = /*MSG0*/"251"; }
    : swatch { color = 252; key = /*MSG0*/"252"; }
    : swatch { color = 253; key = /*MSG0*/"253"; }
    : swatch { color = 254; key = /*MSG0*/"254"; }
    : swatch { color = 255; key = /*MSG0*/"255"; }
}

std_rq_color :column{
    :column {
        :boxed_row {
            fixed_width = true;
            label = /*BASE_DCL_5*/"Standard Colors";
            color_palette_1_9;
        }
        :row {
            :boxed_row {
                fixed_width = true;
                label = /*BASE_DCL_6*/"Gray Shades";
                color_palette_250_255;
            }
            :boxed_row {
                fixed_width = true;
                label = /*BASE_DCL_7*/"Logical Colors";
                :button {
                    label = /*BASE_DCL_8*/"BY&LAYER";
                    key = /*MSG0*/"256";
                }
                :button {
                    label = /*BASE_DCL_9*/"&BYBLOCK";
                    key = /*MSG0*/"000";
                }
            }
        }
    }
    :boxed_column {
        label = /*BASE_DCL_10*/"Full Color Palette";
        :image_button{
            key = /*MSG0*/"hiside";
            width = 40;
            height = 5;
        }
        :image_button{
            key = /*MSG0*/"loside";
            width = 40;
            height = 5;
        }
    }
    :row {
        fixed_width = true;
        alignment = centered;
        children_alignment = bottom;
        :edit12_box {
            label = /*BASE_DCL_11*/"Color:";
            key = /*MSG0*/"color_edit";
            allow_accept = true;
        }
        :swatch {
            key = /*MSG0*/"color_image";
        }
    }
    ok_cancel_help_errtile;
}

//  The preceding are for color-selection dialogs


//  Top and bottom sub-assemblies for the files dialogue
files_topdf : column {
    : edit_box {
        key = /*MSG0*/"pedit";
        label = /*BASE_DCL_12*/"&Pattern:";
        edit_width = 35;
    }
    : row {
        : text {
            label = /*BASE_DCL_13*/"Directory:";
        }
        : text {
            key = /*MSG0*/"dirtext";
            width = 35;
        }
    }
}

files_bottomdf : column {
    : edit_box {
        key = /*MSG0*/"fedit";
        label = /*BASE_DCL_14*/"&File:";
        allow_accept = true;
    }
    ok_cancel_help;
    errtile;
}

